@@ -638,7 +638,8 @@ class ScoreCardModel(object):
                 # 剔除这个特征
                 df0 = df.drop(feat, axis=1)
                 # 重新计算vif
-                mat_df0 = df0.as_matrix()
+                # mat_df0 = df0.as_matrix()
+                mat_df0 = df0.values
                 list_vif = [variance_inflation_factor(mat_df0, i) for i in range(df0.shape[1])]
                 # 如果list_vif中不存在大于阈值vif的情况, 则表示剔除这个特征有效解决共线性
                 if max(list_vif) < vif_thres:
@@ -658,7 +659,8 @@ class ScoreCardModel(object):
             cols_filter.add(feat_candi_miniv)
             # 剔除该特征
             df = df.drop(feat_candi_miniv, axis=1)
-            mat_vif = df.as_matrix()
+            # mat_vif = df.as_matrix()
+            mat_vif = df.values
 
             # 重新计算
             list_featnames = list(df.columns)
@@ -933,18 +935,27 @@ class ScoreCardModel(object):
             if col == self.target:
                 continue
 
-            if col in self.cols_cont:
-                dict_no_to_group = dict(map(reversed, self.dict_cols_to_bins[col].items()))
-                df_bins[col] = df_bins[col].map(dict_no_to_group)
-
             # 创建regroup_badrate
             regroup_badrate = utils.bin_badrate(df_bins, col_name=col, target=self.target)
 
+            # 创建分组编号
+            regroup_badrate['bin_no'] = regroup_badrate.index
+
             # 创建样本占比
             regroup_badrate['pnt_feat_vals'] = regroup_badrate['num_feat_vals'] / df.shape[0]
 
+            # 连续型特征需要做区间转换
+            if col in self.cols_cont:
+                dict_no_to_group = dict(map(reversed, self.dict_cols_to_bins[col].items()))
+                regroup_badrate['bins'] = regroup_badrate['bin_no'].map(dict_no_to_group)
+            else:
+                regroup_badrate['bins'] = regroup_badrate['bin_no']
+
+            # 反转index
+            regroup_badrate = regroup_badrate.set_index('bins')
+
             # 注意regroup_badrate需要排序
-            regroup_badrate = regroup_badrate.sort_index()
+            regroup_badrate = regroup_badrate.sort_values(by='bin_no')
 
             # 开始绘图
             fontdict = {'fontsize': fontsize}
@@ -952,7 +963,9 @@ class ScoreCardModel(object):
             ax[i].bar(regroup_badrate.index, regroup_badrate['pnt_feat_vals'])
             ax[i].set_ylim((0, 1))
             ax[i].set_title("{0}' Badrate".format(col), fontdict=fontdict)
+
             ax[i].set_xticks(regroup_badrate.index)
+
             ax[i].set_xlabel('Group', fontdict=fontdict)
             ax[i].set_ylabel('Pct. of bins', fontdict=fontdict)
             ax[i].tick_params(labelsize=fontsize)
